/***************************************************************************
                          knowitpref.cpp  -  description
                             -------------------
    begin                : czw lis 28 2002
    copyright            : (C) 2002 by Micha Rudolf
    email                : mrudolf@mercury.ci.uw.edu.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qstring.h>
#include <qlabel.h>
#include <qvbox.h>
#include "knowitpref.h"
#include <klocale.h>
#include <kglobal.h>
#include <kiconloader.h>
#include <qdatetime.h>
#include <qlayout.h>
#include <qwhatsthis.h>


void KnowitOptions::save(KConfig* config) const
{
   config->setGroup("General");
   config->writeEntry("Docked", docked);
   config->writeEntry("Autosave", autosave);
   config->writeEntry("Reopen", reopen);
   config->writeEntry("Toolbar", toolbar);   
   config->writeEntry("HorizontalSplit", horizontalSplit);
   config->writeEntry("DefaultName", defaultName);
   config->writeEntry("AlternateTree", alternateTree);
   config->writeEntry("AlternateColor", alternateColor);
   config->writeEntry("AutoCollapse", autoCollapse);
   config->setGroup("Editor");
   config->writeEntry("WordWrap", wordwrap);
   config->setGroup("Templates");
   config->writeEntry("InsertDateFormatString", insertDateFormat);
   config->writeEntry("InsertDateColor", insertDateColor);
   config->writeEntry("InsertDateBold", insertDateBold);
   config->writeEntry("InsertDateItalic", insertDateItalic);
   config->writeEntry("InsertDateUnderline", insertDateUnderline);
}


void KnowitOptions::read(KConfig* config)
{
   config->setGroup("General");
   docked = config->readBoolEntry("Docked", false);
   autosave = config->readNumEntry("Autosave", 0);
   reopen = config->readBoolEntry("Reopen", true);
   toolbar = config->readBoolEntry("Toolbar", true);
   horizontalSplit = config->readNumEntry("HorizontalSplit", true);
   defaultName = config->readEntry("DefaultName", i18n("New note"));
   alternateTree = config->readBoolEntry("AlternateTree", false);
   alternateColor = config->readEntry("AlternateColor", QString("LightYellow"));
   autoCollapse = config->readBoolEntry("AutoCollapse", false);
   config->setGroup("Editor");
   wordwrap = config->readBoolEntry("WordWrap", true);
   config->setGroup("Templates");
   insertDateFormat = config->readEntry("InsertDateFormatString", QString("ddd d MMM yyyy, hh:mm:ss"));
   insertDateColor = config->readEntry("InsertDateColor", QString("Blue"));
   insertDateBold = config->readBoolEntry("InsertDateBold", false);
   insertDateItalic = config->readBoolEntry("InsertDateItalic", true);
   insertDateUnderline = config->readBoolEntry("InsertDateUnderline", false);
}



KnowitPreferences::KnowitPreferences()
   : KDialogBase(Tabbed, i18n("KnowIt Preferences"), Ok|Cancel, Ok)
{
    QVBox* pageGeneral = addVBoxPage(i18n("&General"), i18n("General options"));
    docked = new QCheckBox(i18n("&Dock in System tray"), pageGeneral, "Dock");
    reopen = new QCheckBox(i18n("Open &last file on startup"), pageGeneral, "Reopen");
    QHBox* autosaveBox = new QHBox(pageGeneral);
    new QLabel(i18n("Autosave:"), autosaveBox);
    autosave = new QSpinBox(0, 120, 5, autosaveBox, "Autosave");
    autosave->setPrefix(i18n("every "));
    autosave->setSuffix(i18n(" min."));
    autosave->setSpecialValueText(i18n("Never"));
    QWhatsThis::add(autosave, i18n("Current file will be automatically saved "
       "after the specified interval. Set to <i>never</i> to disable autosave."));

    QVBox* pageGUI = addVBoxPage(i18n("&Interface"), i18n("Interface options"));
    toolbar = new QCheckBox(i18n("Show &toolbar"), pageGUI, "Toolbar");
    horizontalSplit = new QCheckBox(i18n("Split window &horizontally"), pageGUI, "Split");
    QWhatsThis::add(horizontalSplit, i18n("If this option is set, notes tree will "
       "be displayed on the left and the editor on the right (this is default).<br>"
       "Otherwise notes tree will be displayed at the top and the editor at the bottom."));
    QHBox* defaultNameBox = new QHBox(pageGUI);
    new QLabel(i18n("Default note name:"), defaultNameBox);
    defaultName = new KLineEdit(defaultNameBox, "DefaultName");
    QWhatsThis::add(defaultName, i18n("Default name for new notes. It would be "
       "autoselected, so if you often copy text using mouse selection, you may "
       "consider setting default name to none."));
    
    QHBox* alternateBox = new QHBox(pageGUI);
    alternateTree = new QCheckBox(i18n("Alternate colors in list"), alternateBox, "Alternate");
    alternateColor = new KColorButton(QColor("White"), alternateBox, "AlternateColor");
    autoCollapse = new QCheckBox(i18n("Automatically collapse other notes"), pageGUI, "AutoCollapse");
    QWhatsThis::add(autoCollapse, i18n("If this option is set, only current subtree "
       "will be visible, other notes will be automatically collapsed."));
        
    QVBox* pageEditor = addVBoxPage(i18n("&Editor"), i18n("Editor options"));
    wordwrap = new QCheckBox(i18n("Use &word wrap"), pageEditor, "WordWrap");
    
    QVBox* pageTemplates = addVBoxPage(i18n("&Templates"), i18n("Templates configuration"));
    QWhatsThis::add(pageTemplates, i18n("<html>\n"
"<p>These expressions may be used: </p>\n"
"<table>\n"
"<tr><th>d</th><td>the day as number without a leading zero (1-31)</td></tr>\n"
"<tr><th>dd</th><td>the day as number with a leading zero (01-31)</td></tr>\n"
"<tr><th>ddd</th><td>the abbreviated localized day name (e.g. 'Mon'..'Sun')</td></tr>\n"
"<tr><th>dddd</th><td>the long localized day name (e.g. 'Monday'..'Sunday')</td></tr>\n"
"<tr><th>M</th><td>the month as number without a leading zero (1-12)</td></tr>\n"
"<tr><th>MM</th><td>the month as number with a leading zero (01-12)</td></tr>\n"
"<tr><th>MMM</th><td>the abbreviated localized month name (e.g. 'Jan'..'Dec')</td></tr>\n"
"<tr><th>MMMM</th><td>the long localized month name (e.g. 'January'..'December')</td></tr>\n"
"<tr><th>yy</th><td>the year as two digit number (00-99)</td></tr>\n"
"<tr><th>yyyy</th><td>the year as four digit number (1752-8000)</td></tr>\n"
"<tr><th>h</th><td>the hour without a leading zero (0..23 or 1..12 if AM/PM display)</td></tr>\n"
"<tr><th>hh</th><td>the hour with a leading zero (00..23 or 01..12 if AM/PM display)</td></tr>\n"
"<tr><th>m</th><td>the minute without a leading zero (0..59)</td></tr>\n"
"<tr><th>mm</th><td>the minute with a leading zero (00..59)</td></tr>\n"
"<tr><th>s</th><td>the second without a leading zero (0..59)</td></tr>\n"
"<tr><th>ss</th><td>the second with a leading zero (00..59)</td></tr>\n"
"<tr><th>AP</th><td>use AM/PM display</td></tr>\n"
"<tr><th>AP</th><td>use am/pm display</td></tr>\n"
"</table></html>"));

    QHBox* topBox = new QHBox(pageTemplates);
    QLabel * label1 = new QLabel(i18n("Date Format: "), topBox);
    label1->setFixedSize(label1->sizeHint());
    insertDatePreview = new QLabel("", topBox);
    
    QHBox *tmpBox = new QHBox(pageTemplates);
      
    insertDateColorButton = new KColorButton(QColor("Blue"), tmpBox, "InsertDateColorButton");
        
    insertDateFormatEdit = new KLineEdit(tmpBox, "InsertDateFormatEdit");
    
    KIconLoader *loader = KGlobal::iconLoader();
    
    insertDateItalicButton = new QToolButton(tmpBox,"InsertDateItalicButton");
    insertDateItalicButton->setIconSet(QIconSet(loader->loadIcon("text_italic", KIcon::Toolbar)));
    insertDateItalicButton->setToggleButton(true);
    
    insertDateBoldButton = new QToolButton(tmpBox,"InsertDateBoldButton");
    insertDateBoldButton->setIconSet(QIconSet(loader->loadIcon("text_bold", KIcon::Toolbar)));
    insertDateBoldButton->setToggleButton(true);
    
    insertDateUnderlineButton = new QToolButton(tmpBox, "InsertDateUnderlineButton");
    insertDateUnderlineButton->setIconSet(QIconSet(loader->loadIcon("text_under", KIcon::Toolbar)));    
    insertDateUnderlineButton->setToggleButton(true);
    
    pageTemplates->layout()->addItem(new QSpacerItem(0,0,QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding));
    
    insertDateColorButton->setFixedSize(insertDateBoldButton->sizeHint());
    insertDateFormatEdit->setMinimumWidth(6*insertDateBoldButton->sizeHint().width());
    
    
}

void KnowitPreferences::setOptions(const KnowitOptions& Options)
{
   docked->setChecked(Options.docked);
   reopen->setChecked(Options.reopen);
   autosave->setValue(Options.autosave);

   toolbar->setChecked(Options.toolbar);
   horizontalSplit->setChecked(Options.horizontalSplit);
   defaultName->setText(Options.defaultName);
   alternateTree->setChecked(Options.alternateTree);
   alternateColor->setColor(QColor(Options.alternateColor));
   autoCollapse->setChecked(Options.autoCollapse);
      
   wordwrap->setChecked(Options.wordwrap);

   insertDateFormatEdit->setText(Options.insertDateFormat);
   insertDateColorButton->setColor(QColor(Options.insertDateColor));
   insertDateBoldButton->setOn(Options.insertDateBold);
   insertDateItalicButton->setOn(Options.insertDateItalic);
   insertDateUnderlineButton->setOn(Options.insertDateUnderline);
   slotUpdateDatePreview();
   connect(insertDateColorButton, SIGNAL(clicked()), this, SLOT(slotUpdateDatePreview()));
   connect(insertDateFormatEdit, SIGNAL(textChanged (const QString &)), this, SLOT(slotUpdateDatePreview()));
   connect(insertDateItalicButton, SIGNAL(toggled(bool)), this, SLOT(slotUpdateDatePreview()));
   connect(insertDateBoldButton, SIGNAL(toggled(bool)), this, SLOT(slotUpdateDatePreview()));
   connect(insertDateUnderlineButton, SIGNAL(toggled(bool)), this, SLOT(slotUpdateDatePreview()));
}

void KnowitPreferences::slotUpdateDatePreview()
{
   QString str = "<html><p align=\"center\">";
   if(insertDateBoldButton->isOn()) str += "<b>";
   if(insertDateItalicButton->isOn()) str +="<i>";
   if(insertDateUnderlineButton->isOn()) str += "<u>";
   str += "<font COLOR=\""+insertDateColorButton->color().name()+"\">";
   str += QString("%1").arg(QDateTime::currentDateTime().toString(insertDateFormatEdit->text()));
   str += "</font>";
   if(insertDateUnderlineButton->isOn()) str += "</u>";
   if(insertDateItalicButton->isOn()) str +="</i>";
   if(insertDateBoldButton->isOn()) str += "</b>";
   str += "</p></html>";
   insertDatePreview->setPaletteBackgroundColor(QColor("White"));
   insertDatePreview->setText(str);
}


KnowitOptions KnowitPreferences::getOptions() const
{
   KnowitOptions Options;
   Options.docked = docked->isChecked();
   Options.reopen = reopen->isChecked();
   Options.autosave = autosave->value();
   Options.toolbar = toolbar->isChecked();   
   Options.horizontalSplit = horizontalSplit->isChecked();
   Options.defaultName = defaultName->text();
   Options.alternateTree = alternateTree->isChecked();
   Options.alternateColor = alternateColor->color().name();
   Options.autoCollapse = autoCollapse->isChecked();
   Options.wordwrap = wordwrap->isChecked();
   Options.insertDateFormat = insertDateFormatEdit->text();
   Options.insertDateColor = insertDateColorButton->color().name();
   Options.insertDateBold = insertDateBoldButton->isOn();
   Options.insertDateItalic = insertDateItalicButton->isOn();
   Options.insertDateUnderline = insertDateUnderlineButton->isOn();
   return Options;
}

